@@ -90,10 +90,23 @@ def gen_design_table(fun_control: dict, spot: object = None, tablefmt="github")
 
 
 def compare_two_tree_models(model1, model2, headers=["Parameter", "Default", "Spot"]):
-    keys = model1[1].summary.keys()
-    values1 = model1[1].summary.values()
-    values2 = model2[1].summary.values()
+    keys = model1.summary.keys()
+    values1 = model1.summary.values()
+    values2 = model2.summary.values()
     tbl = []
     for key, value1, value2 in zip(keys, values1, values2):
         tbl.append([key, value1, value2])
     return tabulate(tbl, headers=headers, numalign="right", tablefmt="github")
+
+
+def generate_config_id(config):
+    """Generates a unique id for a configuration.
+    Args:
+        config (dict): A dictionary with the configuration.
+    Returns:
+        str: A unique id for the configuration.
+    """
+    config_id = ""
+    for key in config:
+        config_id += str(config[key]) + "_"
+    return config_id[:-1]
